@@ -3,6 +3,7 @@ package check
 import (
 	"bytes"
 	"encoding/json"
+	"errors"
 	"fmt"
 	"math"
 	"reflect"
@@ -11,7 +12,7 @@ import (
 	"testing"
 	"time"
 
-	pkgerrors "github.com/pkg/errors"
+	pkgerrors "github.com/pkg/errors" //nolint:depguard // By design.
 	"github.com/powerman/deepequal"
 	"google.golang.org/grpc/status"
 	"google.golang.org/protobuf/proto"
@@ -28,6 +29,7 @@ var (
 // C wraps *testing.T to make it convenient to call checkers in test.
 type C struct {
 	*testing.T
+
 	todo bool
 	must bool
 }
@@ -134,7 +136,7 @@ func (t *C) fail() {
 	stats[t.T].failed.value++
 }
 
-func (t *C) report(ok bool, msg []interface{}, checker string, name []string, args []interface{}) bool { //nolint:revive // False positive.
+func (t *C) report(ok bool, msg []any, checker string, name []string, args []any) bool { //nolint:revive // False positive.
 	t.Helper()
 
 	if ok != t.todo {
@@ -170,8 +172,8 @@ func (t *C) report(ok bool, msg []interface{}, checker string, name []string, ar
 	}
 	failureLong := failure.String()
 
-	wantDiff := len(dump) == 2 && name[0] == nameActual && name[1] == nameExpected
-	if wantDiff { //nolint:nestif // No idea how to simplify.
+	wantDiff := len(dump) == 2 && name[0] == nameActual && name[1] == nameExpected //nolint:gosec // False positive.
+	if wantDiff {                                                                  //nolint:nestif // No idea how to simplify.
 		if reportToGoConvey(dump[0].String(), dump[1].String(), failureShort) == nil {
 			t.Fail()
 		} else {
@@ -194,39 +196,39 @@ func (t *C) report(ok bool, msg []interface{}, checker string, name []string, ar
 	return ok
 }
 
-func (t *C) reportShould1(funcName string, actual interface{}, msg []interface{}, ok bool) bool {
+func (t *C) reportShould1(funcName string, actual any, msg []any, ok bool) bool {
 	t.Helper()
 	return t.report(ok, msg,
 		"Should "+funcName,
 		[]string{nameActual},
-		[]interface{}{actual})
+		[]any{actual})
 }
 
-func (t *C) reportShould2(funcName string, actual, expected interface{}, msg []interface{}, ok bool) bool {
+func (t *C) reportShould2(funcName string, actual, expected any, msg []any, ok bool) bool {
 	t.Helper()
 	return t.report(ok, msg,
 		"Should "+funcName,
 		[]string{nameActual, nameExpected},
-		[]interface{}{actual, expected})
+		[]any{actual, expected})
 }
 
-func (t *C) report0(msg []interface{}, ok bool) bool {
+func (t *C) report0(msg []any, ok bool) bool {
 	t.Helper()
 	return t.report(ok, msg,
 		callerFuncName(1),
 		[]string{},
-		[]interface{}{})
+		[]any{})
 }
 
-func (t *C) report1(actual interface{}, msg []interface{}, ok bool) bool {
+func (t *C) report1(actual any, msg []any, ok bool) bool {
 	t.Helper()
 	return t.report(ok, msg,
 		callerFuncName(1),
 		[]string{nameActual},
-		[]interface{}{actual})
+		[]any{actual})
 }
 
-func (t *C) report2(actual, expected interface{}, msg []interface{}, ok bool) bool {
+func (t *C) report2(actual, expected any, msg []any, ok bool) bool {
 	t.Helper()
 	checker, arg2Name := callerFuncName(1), nameExpected
 	if strings.Contains(checker, "Match") {
@@ -235,10 +237,10 @@ func (t *C) report2(actual, expected interface{}, msg []interface{}, ok bool) bo
 	return t.report(ok, msg,
 		checker,
 		[]string{nameActual, arg2Name},
-		[]interface{}{actual, expected})
+		[]any{actual, expected})
 }
 
-func (t *C) report3(actual, expected1, expected2 interface{}, msg []interface{}, ok bool) bool {
+func (t *C) report3(actual, expected1, expected2 any, msg []any, ok bool) bool {
 	t.Helper()
 	checker, arg2Name, arg3Name := callerFuncName(1), "arg1", "arg2"
 	switch {
@@ -252,15 +254,15 @@ func (t *C) report3(actual, expected1, expected2 interface{}, msg []interface{},
 	return t.report(ok, msg,
 		checker,
 		[]string{nameActual, arg2Name, arg3Name},
-		[]interface{}{actual, expected1, expected2})
+		[]any{actual, expected1, expected2})
 }
 
 // Must interrupt test using t.FailNow if called with false value.
 //
 // This provides an easy way to turn any check into assertion:
 //
-//   t.Must(t.Nil(err))
-func (t *C) Must(continueTest bool, msg ...interface{}) { //nolint:revive // False positive.
+//	t.Must(t.Nil(err))
+func (t *C) Must(continueTest bool, msg ...any) { //nolint:revive // False positive.
 	t.Helper()
 	t.report0(msg, continueTest)
 	if !continueTest {
@@ -270,9 +272,9 @@ func (t *C) Must(continueTest bool, msg ...interface{}) { //nolint:revive // Fal
 
 type (
 	// ShouldFunc1 is like Nil or Zero.
-	ShouldFunc1 func(t *C, actual interface{}) bool
+	ShouldFunc1 func(t *C, actual any) bool
 	// ShouldFunc2 is like Equal or Match.
-	ShouldFunc2 func(t *C, actual, expected interface{}) bool
+	ShouldFunc2 func(t *C, actual, expected any) bool
 )
 
 // Should use user-provided check function to do actual check.
@@ -294,19 +296,19 @@ type (
 //		t := check.T(tt)
 //		t.Should(bePositive, 42, "custom check!!!")
 //	}
-func (t *C) Should(anyShouldFunc interface{}, args ...interface{}) bool {
+func (t *C) Should(anyShouldFunc any, args ...any) bool {
 	t.Helper()
 	switch f := anyShouldFunc.(type) {
-	case func(t *C, actual interface{}) bool:
+	case func(t *C, actual any) bool:
 		return t.should1(f, args...)
-	case func(t *C, actual, expected interface{}) bool:
+	case func(t *C, actual, expected any) bool:
 		return t.should2(f, args...)
 	default:
 		panic("anyShouldFunc is not a ShouldFunc1 or ShouldFunc2")
 	}
 }
 
-func (t *C) should1(f ShouldFunc1, args ...interface{}) bool {
+func (t *C) should1(f ShouldFunc1, args ...any) bool {
 	t.Helper()
 	if len(args) < 1 {
 		panic("not enough params for " + funcName(f))
@@ -316,7 +318,7 @@ func (t *C) should1(f ShouldFunc1, args ...interface{}) bool {
 		f(t, actual))
 }
 
-func (t *C) should2(f ShouldFunc2, args ...interface{}) bool {
+func (t *C) should2(f ShouldFunc2, args ...any) bool {
 	t.Helper()
 	const minArgs = 2
 	if len(args) < minArgs {
@@ -361,13 +363,13 @@ func (t *C) should2(f ShouldFunc2, args ...interface{}) bool {
 // really, so Nil(uintptr(0)) will fail. Nil(unsafe.Pointer(nil)) will
 // also fail, for the same reason. Please do not use this and consider
 // this behaviour undefined, because it may change in the future.
-func (t *C) Nil(actual interface{}, msg ...interface{}) bool {
+func (t *C) Nil(actual any, msg ...any) bool {
 	t.Helper()
 	return t.report1(actual, msg,
 		isNil(actual))
 }
 
-func isNil(actual interface{}) bool {
+func isNil(actual any) bool {
 	switch val := reflect.ValueOf(actual); val.Kind() {
 	case reflect.Invalid:
 		return actual == nil
@@ -387,7 +389,7 @@ func isNil(actual interface{}) bool {
 // NotNil checks for actual != nil.
 //
 // See Nil about subtle case in check logic.
-func (t *C) NotNil(actual interface{}, msg ...interface{}) bool {
+func (t *C) NotNil(actual any, msg ...any) bool {
 	t.Helper()
 	return t.report0(msg,
 		!isNil(actual))
@@ -396,7 +398,7 @@ func (t *C) NotNil(actual interface{}, msg ...interface{}) bool {
 // Error is equivalent to Log followed by Fail.
 //
 // It is like t.Errorf with TODO() and statistics support.
-func (t *C) Error(msg ...interface{}) {
+func (t *C) Error(msg ...any) {
 	t.Helper()
 	t.report0(msg, false)
 }
@@ -410,14 +412,14 @@ func (t *C) Error(msg ...interface{}) {
 //	if !cond {
 //		t.Errorf(msg...)
 //	}
-func (t *C) True(cond bool, msg ...interface{}) bool {
+func (t *C) True(cond bool, msg ...any) bool {
 	t.Helper()
 	return t.report0(msg,
 		cond)
 }
 
 // False checks for cond == false.
-func (t *C) False(cond bool, msg ...interface{}) bool {
+func (t *C) False(cond bool, msg ...any) bool {
 	t.Helper()
 	return t.report0(msg,
 		!cond)
@@ -426,13 +428,13 @@ func (t *C) False(cond bool, msg ...interface{}) bool {
 // Equal checks for actual == expected.
 //
 // Note: For time.Time it uses actual.Equal(expected) instead.
-func (t *C) Equal(actual, expected interface{}, msg ...interface{}) bool {
+func (t *C) Equal(actual, expected any, msg ...any) bool {
 	t.Helper()
 	return t.report2(actual, expected, msg,
 		isEqual(actual, expected))
 }
 
-func isEqual(actual, expected interface{}) bool {
+func isEqual(actual, expected any) bool {
 	switch actual := actual.(type) {
 	case time.Time:
 		return actual.Equal(expected.(time.Time))
@@ -442,20 +444,20 @@ func isEqual(actual, expected interface{}) bool {
 }
 
 // EQ is a synonym for Equal.
-func (t *C) EQ(actual, expected interface{}, msg ...interface{}) bool {
+func (t *C) EQ(actual, expected any, msg ...any) bool {
 	t.Helper()
 	return t.Equal(actual, expected, msg...)
 }
 
 // NotEqual checks for actual != expected.
-func (t *C) NotEqual(actual, expected interface{}, msg ...interface{}) bool {
+func (t *C) NotEqual(actual, expected any, msg ...any) bool {
 	t.Helper()
 	return t.report2(actual, expected, msg,
 		!isEqual(actual, expected))
 }
 
 // NE is a synonym for NotEqual.
-func (t *C) NE(actual, expected interface{}, msg ...interface{}) bool {
+func (t *C) NE(actual, expected any, msg ...any) bool {
 	t.Helper()
 	return t.NotEqual(actual, expected, msg...)
 }
@@ -463,7 +465,7 @@ func (t *C) NE(actual, expected interface{}, msg ...interface{}) bool {
 // BytesEqual checks for bytes.Equal(actual, expected).
 //
 // Hint: BytesEqual([]byte{}, []byte(nil)) is true (unlike DeepEqual).
-func (t *C) BytesEqual(actual, expected []byte, msg ...interface{}) bool {
+func (t *C) BytesEqual(actual, expected []byte, msg ...any) bool {
 	t.Helper()
 	return t.report2(actual, expected, msg,
 		bytes.Equal(actual, expected))
@@ -472,7 +474,7 @@ func (t *C) BytesEqual(actual, expected []byte, msg ...interface{}) bool {
 // NotBytesEqual checks for !bytes.Equal(actual, expected).
 //
 // Hint: NotBytesEqual([]byte{}, []byte(nil)) is false (unlike NotDeepEqual).
-func (t *C) NotBytesEqual(actual, expected []byte, msg ...interface{}) bool {
+func (t *C) NotBytesEqual(actual, expected []byte, msg ...any) bool {
 	t.Helper()
 	return t.report1(actual, msg,
 		!bytes.Equal(actual, expected))
@@ -482,7 +484,7 @@ func (t *C) NotBytesEqual(actual, expected []byte, msg ...interface{}) bool {
 // It will also use Equal method for types which implements it
 // (e.g. time.Time, decimal.Decimal, etc.).
 // It will use proto.Equal for protobuf messages.
-func (t *C) DeepEqual(actual, expected interface{}, msg ...interface{}) bool {
+func (t *C) DeepEqual(actual, expected any, msg ...any) bool {
 	t.Helper()
 	protoActual, proto1 := actual.(protoreflect.ProtoMessage)
 	protoExpected, proto2 := expected.(protoreflect.ProtoMessage)
@@ -498,7 +500,7 @@ func (t *C) DeepEqual(actual, expected interface{}, msg ...interface{}) bool {
 // It will also use Equal method for types which implements it
 // (e.g. time.Time, decimal.Decimal, etc.).
 // It will use proto.Equal for protobuf messages.
-func (t *C) NotDeepEqual(actual, expected interface{}, msg ...interface{}) bool {
+func (t *C) NotDeepEqual(actual, expected any, msg ...any) bool {
 	t.Helper()
 	protoActual, proto1 := actual.(protoreflect.ProtoMessage)
 	protoExpected, proto2 := expected.(protoreflect.ProtoMessage)
@@ -521,7 +523,7 @@ func (t *C) NotDeepEqual(actual, expected interface{}, msg ...interface{}) bool
 //   - fmt.Stringer - will match with actual.String()
 //   - error        - will match with actual.Error()
 //   - nil          - will not match (even with empty regex)
-func (t *C) Match(actual, regex interface{}, msg ...interface{}) bool {
+func (t *C) Match(actual, regex any, msg ...any) bool {
 	t.Helper()
 	ok := isMatch(&actual, regex)
 	return t.report2(actual, regex, msg,
@@ -530,7 +532,7 @@ func (t *C) Match(actual, regex interface{}, msg ...interface{}) bool {
 
 // isMatch updates actual to be a real string used for matching, to make
 // dump easier to understand, but this result in losing type information.
-func isMatch(actual *interface{}, regex interface{}) bool { //nolint:gocritic // False positive.
+func isMatch(actual *any, regex any) bool {
 	if *actual == nil {
 		return false
 	}
@@ -548,7 +550,7 @@ func isMatch(actual *interface{}, regex interface{}) bool { //nolint:gocritic //
 	panic("regex is not a *regexp.Regexp or string")
 }
 
-func stringify(arg *interface{}) bool { //nolint:gocritic // False positive.
+func stringify(arg *any) bool {
 	switch v := (*arg).(type) {
 	case nil:
 		return false
@@ -577,7 +579,7 @@ func stringify(arg *interface{}) bool { //nolint:gocritic // False positive.
 // NotMatch checks for !regex.MatchString(actual).
 //
 // See Match about supported actual/regex types and check logic.
-func (t *C) NotMatch(actual, regex interface{}, msg ...interface{}) bool {
+func (t *C) NotMatch(actual, regex any, msg ...any) bool {
 	t.Helper()
 	ok := !isMatch(&actual, regex)
 	return t.report2(actual, regex, msg,
@@ -596,13 +598,13 @@ func (t *C) NotMatch(actual, regex interface{}, msg ...interface{}) bool {
 //
 // Hint: In a map it looks for a value, if you need to look for a key -
 // use HasKey instead.
-func (t *C) Contains(actual, expected interface{}, msg ...interface{}) bool {
+func (t *C) Contains(actual, expected any, msg ...any) bool {
 	t.Helper()
 	return t.report2(actual, expected, msg,
 		isContains(actual, expected))
 }
 
-func isContains(actual, expected interface{}) (found bool) {
+func isContains(actual, expected any) (found bool) {
 	switch valActual := reflect.ValueOf(actual); valActual.Kind() { //nolint:exhaustive // Covered by default case.
 	case reflect.String:
 		strActual := valActual.Convert(typString).Interface().(string) //nolint:forcetypeassert // False positive.
@@ -639,38 +641,38 @@ func isContains(actual, expected interface{}) (found bool) {
 // NotContains checks is actual not contains substring/element expected.
 //
 // See Contains about supported actual/expected types and check logic.
-func (t *C) NotContains(actual, expected interface{}, msg ...interface{}) bool {
+func (t *C) NotContains(actual, expected any, msg ...any) bool {
 	t.Helper()
 	return t.report2(actual, expected, msg,
 		!isContains(actual, expected))
 }
 
 // HasKey checks is actual has key expected.
-func (t *C) HasKey(actual, expected interface{}, msg ...interface{}) bool {
+func (t *C) HasKey(actual, expected any, msg ...any) bool {
 	t.Helper()
 	return t.report2(actual, expected, msg,
 		hasKey(actual, expected))
 }
 
-func hasKey(actual, expected interface{}) bool {
+func hasKey(actual, expected any) bool {
 	return reflect.ValueOf(actual).MapIndex(reflect.ValueOf(expected)).IsValid()
 }
 
 // NotHasKey checks is actual has no key expected.
-func (t *C) NotHasKey(actual, expected interface{}, msg ...interface{}) bool {
+func (t *C) NotHasKey(actual, expected any, msg ...any) bool {
 	t.Helper()
 	return t.report2(actual, expected, msg,
 		!hasKey(actual, expected))
 }
 
 // Zero checks is actual is zero value of it's type.
-func (t *C) Zero(actual interface{}, msg ...interface{}) bool {
+func (t *C) Zero(actual any, msg ...any) bool {
 	t.Helper()
 	return t.report1(actual, msg,
 		isZero(actual))
 }
 
-func isZero(actual interface{}) bool {
+func isZero(actual any) bool {
 	if isNil(actual) {
 		return true
 	} else if typ := reflect.TypeOf(actual); typ.Comparable() {
@@ -691,14 +693,14 @@ func isZero(actual interface{}) bool {
 }
 
 // NotZero checks is actual is not zero value of it's type.
-func (t *C) NotZero(actual interface{}, msg ...interface{}) bool {
+func (t *C) NotZero(actual any, msg ...any) bool {
 	t.Helper()
 	return t.report1(actual, msg,
 		!isZero(actual))
 }
 
 // Len checks is len(actual) == expected.
-func (t *C) Len(actual interface{}, expected int, msg ...interface{}) bool {
+func (t *C) Len(actual any, expected int, msg ...any) bool {
 	t.Helper()
 	l := reflect.ValueOf(actual).Len()
 	return t.report2(l, expected, msg,
@@ -706,7 +708,7 @@ func (t *C) Len(actual interface{}, expected int, msg ...interface{}) bool {
 }
 
 // NotLen checks is len(actual) != expected.
-func (t *C) NotLen(actual interface{}, expected int, msg ...interface{}) bool {
+func (t *C) NotLen(actual any, expected int, msg ...any) bool {
 	t.Helper()
 	l := reflect.ValueOf(actual).Len()
 	return t.report2(l, expected, msg,
@@ -715,23 +717,29 @@ func (t *C) NotLen(actual interface{}, expected int, msg ...interface{}) bool {
 
 // Err checks is actual error is the same as expected error.
 //
+// If errors.Is() fails then it'll use more sofiscated logic:
+//
 // It tries to recursively unwrap actual before checking using
 // errors.Unwrap() and github.com/pkg/errors.Cause().
+// In case of multi-error (Unwrap() []error) it use only first error.
 //
 // It will use proto.Equal for gRPC status errors.
 //
 // They may be a different instances, but must have same type and value.
 //
 // Checking for nil is okay, but using Nil(actual) instead is more clean.
-func (t *C) Err(actual, expected error, msg ...interface{}) bool {
+func (t *C) Err(actual, expected error, msg ...any) bool {
 	t.Helper()
 	actual2 := unwrapErr(actual)
 	equal := fmt.Sprintf("%#v", actual2) == fmt.Sprintf("%#v", expected)
-	_, proto1 := actual2.(interface{ GRPCStatus() *status.Status })  //nolint:errorlint // False positive.
-	_, proto2 := expected.(interface{ GRPCStatus() *status.Status }) //nolint:errorlint // False positive.
+	_, proto1 := actual2.(interface{ GRPCStatus() *status.Status })
+	_, proto2 := expected.(interface{ GRPCStatus() *status.Status })
 	if proto1 || proto2 {
 		equal = proto.Equal(status.Convert(actual2).Proto(), status.Convert(expected).Proto())
 	}
+	if !equal {
+		equal = errors.Is(actual, expected)
+	}
 	return t.report2(actual, expected, msg, equal)
 }
 
@@ -740,11 +748,16 @@ func unwrapErr(err error) (actual error) {
 	actual = err
 	for {
 		actual = pkgerrors.Cause(actual)
-		wrapped, ok := actual.(interface{ Unwrap() error }) //nolint:errorlint // False positive.
-		if !ok {
-			break
+		var unwrapped error
+		switch wrapped := actual.(type) { //nolint:errorlint // False positive.
+		case interface{ Unwrap() error }:
+			unwrapped = wrapped.Unwrap()
+		case interface{ Unwrap() []error }:
+			unwrappeds := wrapped.Unwrap()
+			if len(unwrappeds) > 0 {
+				unwrapped = unwrappeds[0]
+			}
 		}
-		unwrapped := wrapped.Unwrap()
 		if unwrapped == nil {
 			break
 		}
@@ -757,28 +770,34 @@ func unwrapErr(err error) (actual error) {
 //
 // It tries to recursively unwrap actual before checking using
 // errors.Unwrap() and github.com/pkg/errors.Cause().
+// In case of multi-error (Unwrap() []error) it use only first error.
 //
 // It will use !proto.Equal for gRPC status errors.
 //
 // They must have either different types or values (or one should be nil).
 // Different instances with same type and value will be considered the
 // same error, and so is both nil.
-func (t *C) NotErr(actual, expected error, msg ...interface{}) bool {
+//
+// Finally it'll use !errors.Is().
+func (t *C) NotErr(actual, expected error, msg ...any) bool {
 	t.Helper()
 	actual2 := unwrapErr(actual)
 	notEqual := fmt.Sprintf("%#v", actual2) != fmt.Sprintf("%#v", expected)
-	_, proto1 := actual2.(interface{ GRPCStatus() *status.Status })  //nolint:errorlint // False positive.
-	_, proto2 := expected.(interface{ GRPCStatus() *status.Status }) //nolint:errorlint // False positive.
+	_, proto1 := actual2.(interface{ GRPCStatus() *status.Status })
+	_, proto2 := expected.(interface{ GRPCStatus() *status.Status })
 	if proto1 || proto2 {
 		notEqual = !proto.Equal(status.Convert(actual2).Proto(), status.Convert(expected).Proto())
 	}
+	if notEqual {
+		notEqual = !errors.Is(actual, expected)
+	}
 	return t.report1(actual, msg, notEqual)
 }
 
 // Panic checks is actual() panics.
 //
 // It is able to detect panic(nil)… but you should try to avoid using this.
-func (t *C) Panic(actual func(), msg ...interface{}) bool {
+func (t *C) Panic(actual func(), msg ...any) bool {
 	t.Helper()
 	didPanic := true
 	func() {
@@ -793,7 +812,7 @@ func (t *C) Panic(actual func(), msg ...interface{}) bool {
 // NotPanic checks is actual() don't panics.
 //
 // It is able to detect panic(nil)… but you should try to avoid using this.
-func (t *C) NotPanic(actual func(), msg ...interface{}) bool {
+func (t *C) NotPanic(actual func(), msg ...any) bool {
 	t.Helper()
 	didPanic := true
 	func() {
@@ -810,9 +829,9 @@ func (t *C) NotPanic(actual func(), msg ...interface{}) bool {
 // Regex type can be either *regexp.Regexp or string.
 //
 // In case of panic(nil) it will match like panic("<nil>").
-func (t *C) PanicMatch(actual func(), regex interface{}, msg ...interface{}) bool {
+func (t *C) PanicMatch(actual func(), regex any, msg ...any) bool {
 	t.Helper()
-	var panicVal interface{}
+	var panicVal any
 	didPanic := true
 	func() {
 		defer func() { panicVal = recover() }()
@@ -840,9 +859,9 @@ func (t *C) PanicMatch(actual func(), regex interface{}, msg ...interface{}) boo
 // Regex type can be either *regexp.Regexp or string.
 //
 // In case of panic(nil) it will match like panic("<nil>").
-func (t *C) PanicNotMatch(actual func(), regex interface{}, msg ...interface{}) bool {
+func (t *C) PanicNotMatch(actual func(), regex any, msg ...any) bool {
 	t.Helper()
-	var panicVal interface{}
+	var panicVal any
 	didPanic := true
 	func() {
 		defer func() { panicVal = recover() }()
@@ -873,13 +892,13 @@ func (t *C) PanicNotMatch(actual func(), regex interface{}, msg ...interface{})
 //   - floats
 //   - strings
 //   - time.Time
-func (t *C) Less(actual, expected interface{}, msg ...interface{}) bool {
+func (t *C) Less(actual, expected any, msg ...any) bool {
 	t.Helper()
 	return t.report2(actual, expected, msg,
 		isLess(actual, expected))
 }
 
-func isLess(actual, expected interface{}) bool {
+func isLess(actual, expected any) bool {
 	switch v1, v2 := reflect.ValueOf(actual), reflect.ValueOf(expected); v1.Kind() { //nolint:exhaustive // Covered by default case.
 	case reflect.Int, reflect.Int8, reflect.Int16, reflect.Int32, reflect.Int64:
 		return v1.Int() < v2.Int()
@@ -898,7 +917,7 @@ func isLess(actual, expected interface{}) bool {
 }
 
 // LT is a synonym for Less.
-func (t *C) LT(actual, expected interface{}, msg ...interface{}) bool {
+func (t *C) LT(actual, expected any, msg ...any) bool {
 	t.Helper()
 	return t.Less(actual, expected, msg...)
 }
@@ -911,13 +930,13 @@ func (t *C) LT(actual, expected interface{}, msg ...interface{}) bool {
 //   - floats
 //   - strings
 //   - time.Time
-func (t *C) LessOrEqual(actual, expected interface{}, msg ...interface{}) bool {
+func (t *C) LessOrEqual(actual, expected any, msg ...any) bool {
 	t.Helper()
 	return t.report2(actual, expected, msg,
 		!isGreater(actual, expected))
 }
 
-func isGreater(actual, expected interface{}) bool {
+func isGreater(actual, expected any) bool {
 	switch v1, v2 := reflect.ValueOf(actual), reflect.ValueOf(expected); v1.Kind() { //nolint:exhaustive // Covered by default case.
 	case reflect.Int, reflect.Int8, reflect.Int16, reflect.Int32, reflect.Int64:
 		return v1.Int() > v2.Int()
@@ -936,7 +955,7 @@ func isGreater(actual, expected interface{}) bool {
 }
 
 // LE is a synonym for LessOrEqual.
-func (t *C) LE(actual, expected interface{}, msg ...interface{}) bool {
+func (t *C) LE(actual, expected any, msg ...any) bool {
 	t.Helper()
 	return t.LessOrEqual(actual, expected, msg...)
 }
@@ -949,14 +968,14 @@ func (t *C) LE(actual, expected interface{}, msg ...interface{}) bool {
 //   - floats
 //   - strings
 //   - time.Time
-func (t *C) Greater(actual, expected interface{}, msg ...interface{}) bool {
+func (t *C) Greater(actual, expected any, msg ...any) bool {
 	t.Helper()
 	return t.report2(actual, expected, msg,
 		isGreater(actual, expected))
 }
 
 // GT is a synonym for Greater.
-func (t *C) GT(actual, expected interface{}, msg ...interface{}) bool {
+func (t *C) GT(actual, expected any, msg ...any) bool {
 	t.Helper()
 	return t.Greater(actual, expected, msg...)
 }
@@ -969,14 +988,14 @@ func (t *C) GT(actual, expected interface{}, msg ...interface{}) bool {
 //   - floats
 //   - strings
 //   - time.Time
-func (t *C) GreaterOrEqual(actual, expected interface{}, msg ...interface{}) bool {
+func (t *C) GreaterOrEqual(actual, expected any, msg ...any) bool {
 	t.Helper()
 	return t.report2(actual, expected, msg,
 		!isLess(actual, expected))
 }
 
 // GE is a synonym for GreaterOrEqual.
-func (t *C) GE(actual, expected interface{}, msg ...interface{}) bool {
+func (t *C) GE(actual, expected any, msg ...any) bool {
 	t.Helper()
 	return t.GreaterOrEqual(actual, expected, msg...)
 }
@@ -989,14 +1008,14 @@ func (t *C) GE(actual, expected interface{}, msg ...interface{}) bool {
 //   - floats
 //   - strings
 //   - time.Time
-func (t *C) Between(actual, min, max interface{}, msg ...interface{}) bool {
+func (t *C) Between(actual, minimum, maximum any, msg ...any) bool {
 	t.Helper()
-	return t.report3(actual, min, max, msg,
-		isBetween(actual, min, max))
+	return t.report3(actual, minimum, maximum, msg,
+		isBetween(actual, minimum, maximum))
 }
 
-func isBetween(actual, min, max interface{}) bool {
-	switch v, vmin, vmax := reflect.ValueOf(actual), reflect.ValueOf(min), reflect.ValueOf(max); v.Kind() { //nolint:exhaustive // Covered by default case.
+func isBetween(actual, minimum, maximum any) bool {
+	switch v, vmin, vmax := reflect.ValueOf(actual), reflect.ValueOf(minimum), reflect.ValueOf(maximum); v.Kind() { //nolint:exhaustive // Covered by default case.
 	case reflect.Int, reflect.Int8, reflect.Int16, reflect.Int32, reflect.Int64:
 		return vmin.Int() < v.Int() && v.Int() < vmax.Int()
 	case reflect.Uint, reflect.Uint8, reflect.Uint16, reflect.Uint32, reflect.Uint64, reflect.Uintptr:
@@ -1007,8 +1026,8 @@ func isBetween(actual, min, max interface{}) bool {
 		return vmin.String() < v.String() && v.String() < vmax.String()
 	default:
 		if actualTime, ok := actual.(time.Time); ok {
-			minTime := min.(time.Time) //nolint:forcetypeassert // Want panic.
-			maxTime := max.(time.Time) //nolint:forcetypeassert // Want panic.
+			minTime := minimum.(time.Time) //nolint:forcetypeassert // Want panic.
+			maxTime := maximum.(time.Time) //nolint:forcetypeassert // Want panic.
 			return minTime.Before(actualTime) && actualTime.Before(maxTime)
 		}
 	}
@@ -1023,10 +1042,10 @@ func isBetween(actual, min, max interface{}) bool {
 //   - floats
 //   - strings
 //   - time.Time
-func (t *C) NotBetween(actual, min, max interface{}, msg ...interface{}) bool {
+func (t *C) NotBetween(actual, minimum, maximum any, msg ...any) bool {
 	t.Helper()
-	return t.report3(actual, min, max, msg,
-		!isBetween(actual, min, max))
+	return t.report3(actual, minimum, maximum, msg,
+		!isBetween(actual, minimum, maximum))
 }
 
 // BetweenOrEqual checks for min <= actual <= max.
@@ -1037,10 +1056,10 @@ func (t *C) NotBetween(actual, min, max interface{}, msg ...interface{}) bool {
 //   - floats
 //   - strings
 //   - time.Time
-func (t *C) BetweenOrEqual(actual, min, max interface{}, msg ...interface{}) bool {
+func (t *C) BetweenOrEqual(actual, minimum, maximum any, msg ...any) bool {
 	t.Helper()
-	return t.report3(actual, min, max, msg,
-		isBetween(actual, min, max) || isEqual(actual, min) || isEqual(actual, max))
+	return t.report3(actual, minimum, maximum, msg,
+		isBetween(actual, minimum, maximum) || isEqual(actual, minimum) || isEqual(actual, maximum))
 }
 
 // NotBetweenOrEqual checks for actual < min or max < actual.
@@ -1051,10 +1070,10 @@ func (t *C) BetweenOrEqual(actual, min, max interface{}, msg ...interface{}) boo
 //   - floats
 //   - strings
 //   - time.Time
-func (t *C) NotBetweenOrEqual(actual, min, max interface{}, msg ...interface{}) bool {
+func (t *C) NotBetweenOrEqual(actual, minimum, maximum any, msg ...any) bool {
 	t.Helper()
-	return t.report3(actual, min, max, msg,
-		!(isBetween(actual, min, max) || isEqual(actual, min) || isEqual(actual, max)))
+	return t.report3(actual, minimum, maximum, msg,
+		!isBetween(actual, minimum, maximum) && !isEqual(actual, minimum) && !isEqual(actual, maximum))
 }
 
 // InDelta checks for expected-delta <= actual <= expected+delta.
@@ -1064,23 +1083,23 @@ func (t *C) NotBetweenOrEqual(actual, min, max interface{}, msg ...interface{})
 //   - unsigned integers
 //   - floats
 //   - time.Time (in this case delta must be time.Duration)
-func (t *C) InDelta(actual, expected, delta interface{}, msg ...interface{}) bool {
+func (t *C) InDelta(actual, expected, delta any, msg ...any) bool {
 	t.Helper()
 	return t.report3(actual, expected, delta, msg,
 		isInDelta(actual, expected, delta))
 }
 
-func isInDelta(actual, expected, delta interface{}) bool {
+func isInDelta(actual, expected, delta any) bool {
 	switch v, e, d := reflect.ValueOf(actual), reflect.ValueOf(expected), reflect.ValueOf(delta); v.Kind() { //nolint:exhaustive // Covered by default case.
 	case reflect.Int, reflect.Int8, reflect.Int16, reflect.Int32, reflect.Int64:
-		min, max := e.Int()-d.Int(), e.Int()+d.Int()
-		return min <= v.Int() && v.Int() <= max
+		minimum, maximum := e.Int()-d.Int(), e.Int()+d.Int()
+		return minimum <= v.Int() && v.Int() <= maximum
 	case reflect.Uint, reflect.Uint8, reflect.Uint16, reflect.Uint32, reflect.Uint64, reflect.Uintptr:
-		min, max := e.Uint()-d.Uint(), e.Uint()+d.Uint()
-		return min <= v.Uint() && v.Uint() <= max
+		minimum, maximum := e.Uint()-d.Uint(), e.Uint()+d.Uint()
+		return minimum <= v.Uint() && v.Uint() <= maximum
 	case reflect.Float32, reflect.Float64:
-		min, max := e.Float()-d.Float(), e.Float()+d.Float()
-		return min <= v.Float() && v.Float() <= max
+		minimum, maximum := e.Float()-d.Float(), e.Float()+d.Float()
+		return minimum <= v.Float() && v.Float() <= maximum
 	default:
 		if actualTime, ok := actual.(time.Time); ok {
 			expectedTime := expected.(time.Time) //nolint:forcetypeassert // Want panic.
@@ -1101,7 +1120,7 @@ func isInDelta(actual, expected, delta interface{}) bool {
 //   - unsigned integers
 //   - floats
 //   - time.Time (in this case delta must be time.Duration)
-func (t *C) NotInDelta(actual, expected, delta interface{}, msg ...interface{}) bool {
+func (t *C) NotInDelta(actual, expected, delta any, msg ...any) bool {
 	t.Helper()
 	return t.report3(actual, expected, delta, msg,
 		!isInDelta(actual, expected, delta))
@@ -1127,14 +1146,14 @@ func (t *C) NotInDelta(actual, expected, delta interface{}, msg ...interface{})
 //   - ~82   when they differs in 10 times
 //   - 99.0+ when actual and expected differs in 200+ times
 //   - 100.0 when only one of actual or expected is 0 or one of them is
-//           positive while another is negative
-func (t *C) InSMAPE(actual, expected interface{}, smape float64, msg ...interface{}) bool {
+//     positive while another is negative
+func (t *C) InSMAPE(actual, expected any, smape float64, msg ...any) bool {
 	t.Helper()
 	return t.report3(actual, expected, smape, msg,
 		isInSMAPE(actual, expected, smape))
 }
 
-func isInSMAPE(actual, expected interface{}, smape float64) bool {
+func isInSMAPE(actual, expected any, smape float64) bool {
 	if !(0 < smape && smape < 100) {
 		panic("smape is not in allowed range: 0 < smape < 100")
 	}
@@ -1151,7 +1170,7 @@ func isInSMAPE(actual, expected interface{}, smape float64) bool {
 // smape.
 //
 // See InSMAPE about supported actual/expected types and check logic.
-func (t *C) NotInSMAPE(actual, expected interface{}, smape float64, msg ...interface{}) bool {
+func (t *C) NotInSMAPE(actual, expected any, smape float64, msg ...any) bool {
 	t.Helper()
 	return t.report3(actual, expected, smape, msg,
 		!isInSMAPE(actual, expected, smape))
@@ -1166,7 +1185,7 @@ func (t *C) NotInSMAPE(actual, expected interface{}, smape float64, msg ...inter
 //   - fmt.Stringer - will convert with actual.String()
 //   - error        - will convert with actual.Error()
 //   - nil          - check will always fail
-func (t *C) HasPrefix(actual, expected interface{}, msg ...interface{}) bool {
+func (t *C) HasPrefix(actual, expected any, msg ...any) bool {
 	t.Helper()
 	ok := isHasPrefix(&actual, &expected)
 	return t.report2(actual, expected, msg,
@@ -1175,7 +1194,7 @@ func (t *C) HasPrefix(actual, expected interface{}, msg ...interface{}) bool {
 
 // isHasPrefix updates actual and expected to be a real string used for check,
 // to make dump easier to understand, but this result in losing type information.
-func isHasPrefix(actual, expected *interface{}) bool { //nolint:gocritic // False positive.
+func isHasPrefix(actual, expected *any) bool {
 	if *actual == nil || *expected == nil {
 		return false
 	}
@@ -1191,7 +1210,7 @@ func isHasPrefix(actual, expected *interface{}) bool { //nolint:gocritic // Fals
 // NotHasPrefix checks for !strings.HasPrefix(actual, expected).
 //
 // See HasPrefix about supported actual/expected types and check logic.
-func (t *C) NotHasPrefix(actual, expected interface{}, msg ...interface{}) bool {
+func (t *C) NotHasPrefix(actual, expected any, msg ...any) bool {
 	t.Helper()
 	ok := !isHasPrefix(&actual, &expected)
 	return t.report2(actual, expected, msg,
@@ -1207,7 +1226,7 @@ func (t *C) NotHasPrefix(actual, expected interface{}, msg ...interface{}) bool
 //   - fmt.Stringer - will convert with actual.String()
 //   - error        - will convert with actual.Error()
 //   - nil          - check will always fail
-func (t *C) HasSuffix(actual, expected interface{}, msg ...interface{}) bool {
+func (t *C) HasSuffix(actual, expected any, msg ...any) bool {
 	t.Helper()
 	ok := isHasSuffix(&actual, &expected)
 	return t.report2(actual, expected, msg,
@@ -1216,7 +1235,7 @@ func (t *C) HasSuffix(actual, expected interface{}, msg ...interface{}) bool {
 
 // isHasSuffix updates actual and expected to be a real string used for check,
 // to make dump easier to understand, but this result in losing type information.
-func isHasSuffix(actual, expected *interface{}) bool { //nolint:gocritic // False positive.
+func isHasSuffix(actual, expected *any) bool {
 	if *actual == nil || *expected == nil {
 		return false
 	}
@@ -1232,7 +1251,7 @@ func isHasSuffix(actual, expected *interface{}) bool { //nolint:gocritic // Fals
 // NotHasSuffix checks for !strings.HasSuffix(actual, expected).
 //
 // See HasSuffix about supported actual/expected types and check logic.
-func (t *C) NotHasSuffix(actual, expected interface{}, msg ...interface{}) bool {
+func (t *C) NotHasSuffix(actual, expected any, msg ...any) bool {
 	t.Helper()
 	ok := !isHasSuffix(&actual, &expected)
 	return t.report2(actual, expected, msg,
@@ -1251,7 +1270,7 @@ func (t *C) NotHasSuffix(actual, expected interface{}, msg ...interface{}) bool
 //
 // In case any of actual or expected is nil or empty or (for string or
 // []byte) is invalid JSON - check will fail.
-func (t *C) JSONEqual(actual, expected interface{}, msg ...interface{}) bool {
+func (t *C) JSONEqual(actual, expected any, msg ...any) bool {
 	t.Helper()
 	ok := isJSONEqual(actual, expected)
 	if !ok {
@@ -1266,13 +1285,13 @@ func (t *C) JSONEqual(actual, expected interface{}, msg ...interface{}) bool {
 		ok)
 }
 
-func isJSONEqual(actual, expected interface{}) bool {
+func isJSONEqual(actual, expected any) bool {
 	jsonActual, jsonExpected := jsonify(actual), jsonify(expected)
 	return len(jsonActual) != 0 && len(jsonExpected) != 0 &&
 		bytes.Equal(jsonActual, jsonExpected)
 }
 
-func jsonify(arg interface{}) json.RawMessage {
+func jsonify(arg any) json.RawMessage {
 	switch v := (arg).(type) {
 	case nil:
 		return nil
@@ -1286,7 +1305,7 @@ func jsonify(arg interface{}) json.RawMessage {
 	}
 	buf := reflect.ValueOf(arg).Convert(typBytes).Interface().([]byte) //nolint:forcetypeassert // Want panic.
 
-	var v interface{}
+	var v any
 	err := json.Unmarshal(buf, &v)
 	if err != nil {
 		return nil
@@ -1299,14 +1318,14 @@ func jsonify(arg interface{}) json.RawMessage {
 }
 
 // HasType checks is actual has same type as expected.
-func (t *C) HasType(actual, expected interface{}, msg ...interface{}) bool {
+func (t *C) HasType(actual, expected any, msg ...any) bool {
 	t.Helper()
 	return t.report2(actual, expected, msg,
 		reflect.TypeOf(actual) == reflect.TypeOf(expected))
 }
 
 // NotHasType checks is actual has not same type as expected.
-func (t *C) NotHasType(actual, expected interface{}, msg ...interface{}) bool {
+func (t *C) NotHasType(actual, expected any, msg ...any) bool {
 	t.Helper()
 	return t.report2(actual, expected, msg,
 		reflect.TypeOf(actual) != reflect.TypeOf(expected))
@@ -1317,16 +1336,16 @@ func (t *C) NotHasType(actual, expected interface{}, msg ...interface{}) bool {
 // You must use pointer to interface type in expected:
 //
 //	t.Implements(os.Stdin, (*io.Reader)(nil))
-func (t *C) Implements(actual, expected interface{}, msg ...interface{}) bool {
+func (t *C) Implements(actual, expected any, msg ...any) bool {
 	t.Helper()
 	return t.report2(actual, expected, msg,
 		isImplements(actual, expected))
 }
 
-func isImplements(actual, expected interface{}) bool {
+func isImplements(actual, expected any) bool {
 	typActual := reflect.TypeOf(actual)
 	if typActual.Kind() != reflect.Ptr {
-		typActual = reflect.PtrTo(typActual)
+		typActual = reflect.PointerTo(typActual)
 	}
 	return typActual.Implements(reflect.TypeOf(expected).Elem())
 }
@@ -1336,7 +1355,7 @@ func isImplements(actual, expected interface{}) bool {
 // You must use pointer to interface type in expected:
 //
 //	t.NotImplements(os.Stdin, (*fmt.Stringer)(nil))
-func (t *C) NotImplements(actual, expected interface{}, msg ...interface{}) bool {
+func (t *C) NotImplements(actual, expected any, msg ...any) bool {
 	t.Helper()
 	return t.report2(actual, expected, msg,
 		!isImplements(actual, expected))
